#!/usr/bin/env python3
# -*- coding: utf-8 -*-

import sys
import json

def generuj_wiersze_ogolne(wezel, wiersze, poziom=1, intensywnosc=40):
    """
    Funkcja do generowania wierszy dla wymagań ogólnych.
    """
    nr = wezel.get("nr", "")
    opis = wezel.get("opis", "")
    punkty = wezel.get("atrybuty", {}).get("punkty", "")
    # Zamiana "-1" na "-"
    if punkty == -1:
        punkty = "-"

    # Wcięcie w LaTeX-u (np. 0.5 em na poziom) zależnie od poziomu
    wciecie = r"\hspace{" + f"{0.5 * poziom}em" + "}"  # 0.5em na poziom

    # Kolorowanie dla wymagań ogólnych
    kolor = f"\\cellcolor{{green!{intensywnosc}}}"  # Kolor dla Wymagań Ogólnych

    # Tworzymy wiersz:
    # [wcięcie + nr] & [wcięcie + opis] & [wcięcie + punkty] \\
    linia = f"{kolor}{wciecie}{nr} & {kolor}{wciecie}{opis} & {kolor}{wciecie}{punkty} \\\\"
    wiersze.append(linia)

    # Rekurencja dla dzieci
    for dziecko in wezel.get("wymagania", []):
        generuj_wiersze_ogolne(dziecko, wiersze, poziom + 1, intensywnosc - 20)

def main():
    if len(sys.argv) < 3:
        print("Użycie: skrypt.py plik_wejściowy.json plik_wyjściowy.tex")
        sys.exit(1)

    plik_json = sys.argv[1]
    plik_tekstowy = sys.argv[2]

    # 1. Wczytanie danych JSON z pliku
    with open(plik_json, 'r', encoding='utf-8') as f:
        dane = json.load(f)

    # 2. Bufor na wszystkie wiersze LaTeX
    wiersze = []

    # Dostosowanie szerokości kolumn do 0.1, 0.74 i 0.1 textwidth
    wiersze.append(r"\begin{longtable}{|p{0.1\textwidth}|p{0.74\textwidth}|p{0.1\textwidth}|}")
    wiersze.append(r"\caption{Lista wymagań ogólnych}\label{tab:wo}\\")
    wiersze.append(r"\hline")
    wiersze.append(r"\textbf{Nr} & \textbf{Opis} & \textbf{Punkty} \\")
    wiersze.append(r"\hline")
    # firsthead -> co ma się powtórzyć na kolejnej stronie tabeli
    wiersze.append(r"\endfirsthead")
    wiersze.append(r"\hline")
    wiersze.append(r"\textbf{Nr} & \textbf{Opis} & \textbf{Punkty} \\")
    wiersze.append(r"\hline")
    wiersze.append(r"\endhead")

    # 3. Generowanie wierszy tabeli na podstawie JSON-a
    # Wymagania ogólne
    wiersze.append(r"\hline")
    wiersze.append(r"\cellcolor{green!60}\hspace{0.0em}- & \cellcolor{green!60}\hspace{0.0em}Wymagania ogólne & \cellcolor{green!60}\hspace{0.0em}- \\")
    wiersze.append(r"\hline")
    for element in dane.get("wymagania_ogolne", []):
        generuj_wiersze_ogolne(element, wiersze)
        wiersze.append(r"\hline")  # Dodanie linii odcinającej po każdej sekcji

    # 4. Zakończenie longtable
    wiersze.append(r"\hline")
    wiersze.append(r"\end{longtable}")

    # 5. Zapis do pliku .tex (z polskimi znakami w UTF-8)
    with open(plik_tekstowy, 'w', encoding='utf-8') as f:
        f.write("\n".join(wiersze) + "\n")

if __name__ == "__main__":
    main()

